Citing *echelle*
=================

If you use echelle in your work, please cite the Zenodo listing::

        @software{daniel_hey_2020_3629933,
        author       = {Daniel Hey and
                        Warrick Ball},
        title        = {{Echelle: Dynamic echelle diagrams for 
                        asteroseismology}},
        month        = jan,
        year         = 2020,
        publisher    = {Zenodo},
        version      = {1.4},
        doi          = {10.5281/zenodo.3629933},
        url          = {https://doi.org/10.5281/zenodo.3629933}
        }